mpxplugins/viewplugins/views/podcastview/inc/mpxpodcastcollectionviewimp.h
branchRCL_3
changeset 18 c54d95799c80
parent 0 ff3acec5bc43
child 21 a1247965635c
--- a/mpxplugins/viewplugins/views/podcastview/inc/mpxpodcastcollectionviewimp.h	Wed Mar 31 21:26:33 2010 +0300
+++ b/mpxplugins/viewplugins/views/podcastview/inc/mpxpodcastcollectionviewimp.h	Wed Apr 14 15:54:18 2010 +0300
@@ -24,7 +24,6 @@
 // INCLUDES
 #include <eikspmod.h>
 #include <eikclb.h>
-#include <AknProgressDialog.h>  // MProgressDialogCallback
 #include <eikprogi.h>
 #include <AknWaitDialog.h>
 #include <mpxmediageneraldefs.h>
@@ -154,17 +153,16 @@
     void UpdateOptionMenuL();
 
     /**
      * Start either the delete progress note
      */
-    void StartProgressNoteL();
+    void StartDeleteWaitNoteL();
 
     /**
      * Updates the progress note text and progress bar
      * 
-     * @param	aProgress 		Indicates the portion of the process completed
-     * @param 	aProgressText	Text to be displayed on the progress note  	
+     * @param 	aDeleteText	Text to be displayed on the delete wait note  	
      */
-    void UpdateProcessL(TInt aProgress,const TDesC& aProgressText);
+    void UpdateProcessL(const TDesC& aDeleteNoteText);
 
     /**
      * Updates the copy to remote menu attachment
@@ -678,9 +676,8 @@
     TBool iUpnpFrameworkSupport;
 
     TMPXItemId iSelectedItem;
-    // Progress note for delete
-    CAknProgressDialog*	iProgressDialog;
-    CEikProgressInfo*	iProgressInfo;
+    // Wait note for delete
+    CAknWaitDialog*	iWaitDialog;
 #ifdef UPNP_INCLUDED
     CUpnpCopyCommand* iUpnpCopyCommand; 
 #endif
@@ -154,17 +153,16 @@
 
     /**
-     * Start either the delete progress note
+     * Start either the delete wait note
      */
@@ -154,17 +153,16 @@
 
     /**
-     * Updates the progress note text and progress bar
+     * Updates the delete wait note text
      * 